import { Injectable, Component, Input, Output, ViewChild, HostListener, ElementRef, EventEmitter, Renderer2, forwardRef, NgModule } from '@angular/core';
import { Subject } from 'rxjs/Subject';
import 'rxjs/add/operator/map';
import { HttpClient, HttpRequest, HttpResponse } from '@angular/common/http';
import { NG_VALUE_ACCESSOR, FormBuilder, Validators, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { fromTextArea } from 'codemirror';
import 'codemirror/mode/xml/xml.js';
import { PopoverConfig, PopoverModule } from 'ngx-bootstrap';
import { CommonModule } from '@angular/common';
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var FIVE_SECONDS = 7000;
var MessageService = /** @class */ (function () {
    function MessageService() {
        this.message = new Subject();
    }
    /**
     * @return {?}
     */
    MessageService.prototype.getMessage = function () {
        return this.message.asObservable();
    };
    /**
     * sends message to the editor
     *
     * @param {?} message message to be sent
     * @return {?}
     */
    MessageService.prototype.sendMessage = function (message) {
        this.message.next(message);
        this.clearMessageIn(FIVE_SECONDS);
        return;
    };
    /**
     * a short interval to clear message
     *
     * @param {?} milliseconds time in seconds in which the message has to be cleared
     * @return {?}
     */
    MessageService.prototype.clearMessageIn = function (milliseconds) {
        var _this = this;
        setTimeout(function () {
            _this.message.next(undefined);
        }, milliseconds);
        return;
    };
    return MessageService;
}());
MessageService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
MessageService.ctorParameters = function () { return []; };
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * enable or disable toolbar based on configuration
 *
 * @param {?} value toolbar item
 * @param {?} toolbar toolbar configuration object
 * @return {?}
 */
function canEnableToolbarOptions(value, toolbar) {
    if (value) {
        if (toolbar['length'] === 0) {
            return true;
        }
        else {
            var /** @type {?} */ found = toolbar.filter(function (array) {
                return array.indexOf(value) !== -1;
            });
            return found.length ? true : false;
        }
    }
    else {
        return false;
    }
}
/**
 * set editor configuration
 *
 * @param {?} value configuration via [config] property
 * @param {?} ngxEditorConfig default editor configuration
 * @param {?} input direct configuration inputs via directives
 * @return {?}
 */
function getEditorConfiguration(value, ngxEditorConfig, input) {
    for (var /** @type {?} */ i in ngxEditorConfig) {
        if (i) {
            if (input[i] !== undefined) {
                value[i] = input[i];
            }
            if (!value.hasOwnProperty(i)) {
                value[i] = ngxEditorConfig[i];
            }
        }
    }
    return value;
}
/**
 * return vertical if the element is the resizer property is set to basic
 *
 * @param {?} resizer type of resizer, either basic or stack
 * @return {?}
 */
function canResize(resizer) {
    if (resizer === 'basic') {
        return 'vertical';
    }
    return false;
}
/**
 * save selection when the editor is focussed out
 * @return {?}
 */
function saveSelection() {
    if (window.getSelection) {
        var /** @type {?} */ sel = window.getSelection();
        if (sel.getRangeAt && sel.rangeCount) {
            return sel.getRangeAt(0);
        }
    }
    else if (document.getSelection && document.createRange) {
        return document.createRange();
    }
    return null;
}
/**
 * restore selection when the editor is focussed in
 *
 * @param {?} range saved selection when the editor is focussed out
 * @return {?}
 */
function restoreSelection(range) {
    if (range) {
        if (window.getSelection) {
            var /** @type {?} */ sel = window.getSelection();
            sel.removeAllRanges();
            sel.addRange(range);
            return true;
        }
        else if (document.getSelection && range.select) {
            range.select();
            return true;
        }
    }
    else {
        return false;
    }
}
var Utils = Object.freeze({
    canEnableToolbarOptions: canEnableToolbarOptions,
    getEditorConfiguration: getEditorConfiguration,
    canResize: canResize,
    saveSelection: saveSelection,
    restoreSelection: restoreSelection
});
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var CommandExecutorService = /** @class */ (function () {
    /**
     * @param {?} _http
     * @param {?} _messageService
     */
    function CommandExecutorService(_http, _messageService) {
        this._http = _http;
        this._messageService = _messageService;
        this.savedSelection = undefined;
    }
    /**
     * executes command from the toolbar
     *
     * @param {?} command command to be executed
     * @return {?}
     */
    CommandExecutorService.prototype.execute = function (command) {
        if (command === 'enableObjectResizing') {
            document.execCommand('enableObjectResizing', true, true);
            return;
        }
        if (command === 'blockquote') {
            document.execCommand('formatBlock', false, '<blockquote>');
            return;
        }
        if (command === 'removeBlockquote') {
            document.execCommand('formatBlock', false, 'div');
            return;
        }
        document.execCommand(command, false, null);
    };
    /**
     * @param {?} imageURI
     * @return {?}
     */
    CommandExecutorService.prototype.insertImage = function (imageURI) {
        if (this.savedSelection) {
            if (imageURI) {
                var /** @type {?} */ restored = restoreSelection(this.savedSelection);
                if (restored) {
                    var /** @type {?} */ inserted = document.execCommand('insertImage', false, imageURI);
                    if (!inserted) {
                        throw new Error('Invalid URL');
                    }
                }
            }
        }
        else {
            throw new Error('Range out of the editor');
        }
        return;
    };
    /**
     * @param {?} file
     * @param {?} endPoint
     * @return {?}
     */
    CommandExecutorService.prototype.uploadImage = function (file, endPoint) {
        if (!endPoint) {
            throw new Error('Image Endpoint isn`t provided or invalid');
        }
        var /** @type {?} */ formData = new FormData();
        if (file) {
            formData.append('file', file);
            var /** @type {?} */ req = new HttpRequest('POST', endPoint, formData, {
                reportProgress: true
            });
            return this._http.request(req);
        }
        else {
            throw new Error('Invalid Image');
        }
    };
    /**
     * @param {?} params
     * @return {?}
     */
    CommandExecutorService.prototype.createLink = function (params) {
        if (this.savedSelection) {
            /**
                   * check whether the saved selection contains a range or plain selection
                   */
            if (params.urlNewTab) {
                var /** @type {?} */ newUrl = '<a href="' + params.urlLink + '" target="_blank">' + params.urlText + '</a>';
                if (document.getSelection().type !== 'Range') {
                    var /** @type {?} */ restored = restoreSelection(this.savedSelection);
                    if (restored) {
                        document.execCommand('insertHTML', false, newUrl);
                    }
                    document.execCommand('insertHTML', false, newUrl);
                }
                else {
                    throw new Error('Only new links can be inserted. You cannot edit URL`s');
                }
            }
            else {
                var /** @type {?} */ restored = restoreSelection(this.savedSelection);
                if (restored) {
                    document.execCommand('createLink', false, params.urlLink);
                }
            }
        }
        else {
            throw new Error('Range out of the editor');
        }
        return;
    };
    return CommandExecutorService;
}());
CommandExecutorService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
CommandExecutorService.ctorParameters = function () { return [
    { type: HttpClient, },
    { type: MessageService, },
]; };
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * toolbar default configuration
 */
var ngxEditorConfig = {
    editable: true,
    spellcheck: true,
    height: 'auto',
    minHeight: '0',
    width: 'auto',
    minWidth: '0',
    translate: 'yes',
    enableToolbar: true,
    showToolbar: true,
    placeholder: 'Enter text here...',
    imageEndPoint: '',
    toolbar: [
        ['bold', 'italic', 'underline', 'strikeThrough', 'superscript', 'subscript'],
        ['justifyLeft', 'justifyCenter', 'justifyRight', 'justifyFull', 'indent', 'outdent'],
        ['cut', 'copy', 'delete', 'removeFormat', 'undo', 'redo'],
        ['paragraph', 'blockquote', 'removeBlockquote', 'horizontalLine', 'orderedList', 'unorderedList'],
        ['link', 'unlink', 'image'],
        ['code']
    ]
};
/**
 * codemirror configuaration
 */
var codeMirrorConfig = {
    lineNumbers: true,
    gutter: true,
    lineWrapping: true,
    mode: 'xml',
    htmlMode: true
};
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxEditorComponent = /** @class */ (function () {
    /**
     *
     * @param {?} _elementRef  api to access dom element
     * @param {?} _messageService service to send message to the editor message component
     * @param {?} _commandExecutor executes command from the toolbar
     * @param {?} _renderer access and manipulate the dom element
     */
    function NgxEditorComponent(_elementRef, _messageService, _commandExecutor, _renderer) {
        this._elementRef = _elementRef;
        this._messageService = _messageService;
        this._commandExecutor = _commandExecutor;
        this._renderer = _renderer;
        /**
         * The editor can be resized vertically.
         *
         * `basic` resizer enables the html5 reszier. Check here https://www.w3schools.com/cssref/css3_pr_resize.asp
         *
         * `stack` resizer enable a resizer that looks like as if in https://stackoverflow.com
         */
        this.resizer = 'stack';
        /**
         * The config property is a JSON object
         *
         * All avaibale inputs inputs can be provided in the configuration as JSON
         * inputs provided directly are considered as top priority
         */
        this.config = ngxEditorConfig;
        /**
         * emits `blur` event when focused out from the textarea
         */
        this.blur = new EventEmitter();
        /**
         * emits `focus` event when focused in to the textarea
         */
        this.focus = new EventEmitter();
        this.Utils = Utils;
        this.codeEditorMode = false;
        this.lastViewModel = '';
        this.ngxCodeMirror = undefined;
    }
    /**
     * events
     * @return {?}
     */
    NgxEditorComponent.prototype.onFocus = function () {
        this.enableToolbar = true;
        this.focus.emit('focus');
        return;
    };
    /**
     * @param {?} event
     * @return {?}
     */
    NgxEditorComponent.prototype.onDocumentClick = function (event) {
        this.enableToolbar = !!this._elementRef.nativeElement.contains(event.target);
    };
    /**
     * Executed from the contenteditable section while the input property changes
     * @param {?} html html string from contenteditable
     * @return {?}
     */
    NgxEditorComponent.prototype.onContentChange = function (html) {
        if (typeof this.onChange === 'function') {
            this.onChange(html);
            this.monitorEditor(html);
        }
        return;
    };
    /**
     * @return {?}
     */
    NgxEditorComponent.prototype.onBlur = function () {
        /** save selection if focussed out */
        this._commandExecutor.savedSelection = saveSelection();
        if (typeof this.onTouched === 'function') {
            this.onTouched();
        }
        this.blur.emit('blur');
        return;
    };
    /**
     * resizing text area
     *
     * @param {?} offsetY vertical height of the eidtable portion of the editor
     * @return {?}
     */
    NgxEditorComponent.prototype.resizeTextArea = function (offsetY) {
        var /** @type {?} */ newHeight = parseInt(this.height, 10);
        newHeight += offsetY;
        this.height = newHeight + 'px';
        this.textArea.nativeElement.style.height = this.height;
        /**
             * update code-editor height only on editor mode
             */
        if (this.codeEditorMode) {
            this.ngxCodeMirror.setSize('100%', this.height);
        }
        return;
    };
    /**
     * editor actions, i.e., executes command from toolbar
     *
     * @param {?} commandName name of the command to be executed
     * @return {?}
     */
    NgxEditorComponent.prototype.executeCommand = function (commandName) {
        if (commandName === 'code') {
            this.toggleCodeEditor();
            return;
        }
        try {
            this._commandExecutor.execute(commandName);
        }
        catch (error) {
            this._messageService.sendMessage(error.message);
        }
        return;
    };
    /**
     * Write a new value to the element.
     *
     * @param {?} value value to be executed when there is a change in contenteditable
     * @return {?}
     */
    NgxEditorComponent.prototype.writeValue = function (value) {
        this.monitorEditor(value);
        if (value === null || value === undefined || value === '') {
            return;
        }
        this.refreshView(value);
    };
    /**
     * Set the function to be called
     * when the control receives a change event.
     *
     * @param {?} fn a function
     * @return {?}
     */
    NgxEditorComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    /**
     * Set the function to be called
     * when the control receives a touch event.
     *
     * @param {?} fn a function
     * @return {?}
     */
    NgxEditorComponent.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    /**
     * refresh view/HTML of the editor
     *
     * @param {?} value html string from the editor
     * @return {?}
     */
    NgxEditorComponent.prototype.refreshView = function (value) {
        var /** @type {?} */ normalizedValue = value == null ? '' : value;
        this._renderer.setProperty(this.textArea.nativeElement, 'innerHTML', normalizedValue);
        return;
    };
    /**
     * toggle between codeview and editor
     * @return {?}
     */
    NgxEditorComponent.prototype.toggleCodeEditor = function () {
        this.codeEditorMode = !this.codeEditorMode;
        if (this.codeEditorMode) {
            this.ngxCodeMirror = fromTextArea(this.codeEditor.nativeElement, codeMirrorConfig);
            this._renderer.setStyle(this.textArea.nativeElement, 'display', 'none');
            /** set value of the code editor */
            this.ngxCodeMirror.setValue(this.textArea.nativeElement.innerHTML);
            /** sets height of the code editor as same as the height of the textArea */
            this.ngxCodeMirror.setSize('100%', this.height);
        }
        else {
            /** remove/ destroy code editor */
            this.ngxCodeMirror.toTextArea();
            this._renderer.setStyle(this.textArea.nativeElement, 'display', 'block');
            /** update the model value and html content on the contenteditable */
            this.refreshView(this.ngxCodeMirror.getValue());
            this.onContentChange(this.ngxCodeMirror.getValue());
        }
        return;
    };
    /**
     * monitor text area changes
     * @param {?} value
     * @return {?}
     */
    NgxEditorComponent.prototype.monitorEditor = function (value) {
        if (!value || value === '<br>' || value === '') {
            this._renderer.addClass(this.ngxWrapper.nativeElement, 'show-placeholder');
        }
        else {
            this._renderer.removeClass(this.ngxWrapper.nativeElement, 'show-placeholder');
        }
        return;
    };
    /**
     * returns a json containing input params
     * @return {?}
     */
    NgxEditorComponent.prototype.getCollectiveParams = function () {
        return {
            editable: this.editable,
            spellcheck: this.spellcheck,
            placeholder: this.placeholder,
            translate: this.translate,
            height: this.height,
            minHeight: this.minHeight,
            width: this.width,
            minWidth: this.minWidth,
            enableToolbar: this.enableToolbar,
            showToolbar: this.showToolbar,
            imageEndPoint: this.imageEndPoint,
            toolbar: this.toolbar
        };
    };
    /**
     * @return {?}
     */
    NgxEditorComponent.prototype.ngOnInit = function () {
        /**
             * set configuartion
             */
        this.config = this.Utils.getEditorConfiguration(this.config, ngxEditorConfig, this.getCollectiveParams());
        this.height = this.height || this.textArea.nativeElement.offsetHeight;
        this.executeCommand('enableObjectResizing');
    };
    return NgxEditorComponent;
}());
NgxEditorComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-ngx-editor',
                template: "<div class=\"ngx-editor\" id=\"ngxEditor\" [style.width]=\"config['width']\" [style.minWidth]=\"config['minWidth']\">\n  <app-ngx-editor-toolbar [config]=\"config\" (execute)=\"executeCommand($event)\"></app-ngx-editor-toolbar>\n  <!-- text area -->\n  <div class=\"ngx-wrapper\" #ngxWrapper>\n    <div class=\"ngx-editor-textarea\" [attr.contenteditable]=\"config['editable']\" (input)=\"onContentChange($event.target.innerHTML)\"\n      [attr.translate]=\"config['translate']\" [attr.spellcheck]=\"config['spellcheck']\" [style.height]=\"config['height']\" [style.minHeight]=\"config['minHeight']\"\n      [style.resize]=\"Utils?.canResize(resizer)\" (focus)=\"onFocus()\" (blur)=\"onBlur()\" #ngxTextArea></div>\n    <span class=\"ngx-editor-placeholder\">{{ placeholder || config['placeholder'] }}</span>\n  </div>\n  <textarea #ngxCodeEditor [hidden]=\"true\"></textarea>\n  <app-ngx-editor-message></app-ngx-editor-message>\n  <app-ngx-grippie *ngIf=\"resizer === 'stack'\"></app-ngx-grippie>\n</div>\n",
                styles: [".ngx-editor{\n  position:relative; }\n  .ngx-editor ::ng-deep [contenteditable=true]:empty:before{\n    content:attr(placeholder);\n    display:block;\n    color:#868e96;\n    opacity:1; }\n  .ngx-editor .ngx-wrapper{\n    position:relative; }\n    .ngx-editor .ngx-wrapper .ngx-editor-textarea{\n      min-height:5rem;\n      padding:0.5rem 0.8rem 1rem 0.8rem;\n      border:1px solid #ddd;\n      background-color:transparent;\n      overflow-x:hidden;\n      overflow-y:auto;\n      z-index:2;\n      position:relative; }\n      .ngx-editor .ngx-wrapper .ngx-editor-textarea:focus, .ngx-editor .ngx-wrapper .ngx-editor-textarea.focus{\n        outline:0; }\n      .ngx-editor .ngx-wrapper .ngx-editor-textarea ::ng-deep blockquote{\n        margin-left:1rem;\n        border-left:0.2em solid #dfe2e5;\n        padding-left:0.5rem; }\n    .ngx-editor .ngx-wrapper ::ng-deep p{\n      margin-bottom:0; }\n    .ngx-editor .ngx-wrapper .ngx-editor-placeholder{\n      display:none;\n      position:absolute;\n      top:0;\n      padding:0.5rem 0.8rem 1rem 0.9rem;\n      z-index:1;\n      color:#6c757d;\n      opacity:1; }\n    .ngx-editor .ngx-wrapper.show-placeholder .ngx-editor-placeholder{\n      display:block; }\n  .ngx-editor ::ng-deep .CodeMirror{\n    border:1px solid #ddd;\n    z-index:2; }\n"],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(function () { return NgxEditorComponent; }),
                        multi: true
                    }
                ]
            },] },
];
/** @nocollapse */
NgxEditorComponent.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: MessageService, },
    { type: CommandExecutorService, },
    { type: Renderer2, },
]; };
NgxEditorComponent.propDecorators = {
    "editable": [{ type: Input },],
    "spellcheck": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "translate": [{ type: Input },],
    "height": [{ type: Input },],
    "minHeight": [{ type: Input },],
    "width": [{ type: Input },],
    "minWidth": [{ type: Input },],
    "toolbar": [{ type: Input },],
    "resizer": [{ type: Input },],
    "config": [{ type: Input },],
    "showToolbar": [{ type: Input },],
    "enableToolbar": [{ type: Input },],
    "imageEndPoint": [{ type: Input },],
    "blur": [{ type: Output },],
    "focus": [{ type: Output },],
    "textArea": [{ type: ViewChild, args: ['ngxTextArea',] },],
    "codeEditor": [{ type: ViewChild, args: ['ngxCodeEditor',] },],
    "ngxWrapper": [{ type: ViewChild, args: ['ngxWrapper',] },],
    "onDocumentClick": [{ type: HostListener, args: ['document:click', ['$event'],] },],
};
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxGrippieComponent = /** @class */ (function () {
    /**
     *
     * @param {?} _editorComponent editor component
     */
    function NgxGrippieComponent(_editorComponent) {
        this._editorComponent = _editorComponent;
        this.oldY = 0;
        this.grabber = false;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    NgxGrippieComponent.prototype.onMouseMove = function (event) {
        if (!this.grabber) {
            return;
        }
        this._editorComponent.resizeTextArea(event.clientY - this.oldY);
        this.oldY = event.clientY;
    };
    /**
     * @param {?} event
     * @return {?}
     */
    NgxGrippieComponent.prototype.onMouseUp = function (event) {
        this.grabber = false;
    };
    /**
     * @param {?} event
     * @param {?=} resizer
     * @return {?}
     */
    NgxGrippieComponent.prototype.onResize = function (event, resizer) {
        this.grabber = true;
        this.oldY = event.clientY;
        event.preventDefault();
    };
    return NgxGrippieComponent;
}());
NgxGrippieComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-ngx-grippie',
                template: "<div class=\"ngx-editor-grippie\">\n  <svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" style=\"isolation:isolate\" viewBox=\"651.6 235 26 5\"\n    width=\"26\" height=\"5\">\n    <g id=\"sprites\">\n      <path d=\" M 651.6 235 L 653.6 235 L 653.6 237 L 651.6 237 M 654.6 238 L 656.6 238 L 656.6 240 L 654.6 240 M 660.6 238 L 662.6 238 L 662.6 240 L 660.6 240 M 666.6 238 L 668.6 238 L 668.6 240 L 666.6 240 M 672.6 238 L 674.6 238 L 674.6 240 L 672.6 240 M 657.6 235 L 659.6 235 L 659.6 237 L 657.6 237 M 663.6 235 L 665.6 235 L 665.6 237 L 663.6 237 M 669.6 235 L 671.6 235 L 671.6 237 L 669.6 237 M 675.6 235 L 677.6 235 L 677.6 237 L 675.6 237\"\n        fill=\"rgb(147,153,159)\" />\n    </g>\n  </svg>\n</div>\n",
                styles: [".ngx-editor-grippie{\n  height:9px;\n  background-color:#f1f1f1;\n  position:relative;\n  text-align:center;\n  cursor:s-resize;\n  border:1px solid #ddd;\n  border-top:transparent; }\n  .ngx-editor-grippie svg{\n    position:absolute;\n    top:1.5px;\n    width:50%;\n    right:25%; }\n"]
            },] },
];
/** @nocollapse */
NgxGrippieComponent.ctorParameters = function () { return [
    { type: NgxEditorComponent, },
]; };
NgxGrippieComponent.propDecorators = {
    "onMouseMove": [{ type: HostListener, args: ['document:mousemove', ['$event'],] },],
    "onMouseUp": [{ type: HostListener, args: ['document:mouseup', ['$event'],] },],
    "onResize": [{ type: HostListener, args: ['mousedown', ['$event'],] },],
};
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxEditorMessageComponent = /** @class */ (function () {
    /**
     * @param {?} _messageService service to send message to the editor
     */
    function NgxEditorMessageComponent(_messageService) {
        var _this = this;
        this._messageService = _messageService;
        this.ngxMessage = undefined;
        this._messageService.getMessage().subscribe(function (message) { return _this.ngxMessage = message; });
    }
    /**
     * clears editor message
     * @return {?}
     */
    NgxEditorMessageComponent.prototype.clearMessage = function () {
        this.ngxMessage = undefined;
        return;
    };
    return NgxEditorMessageComponent;
}());
NgxEditorMessageComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-ngx-editor-message',
                template: "<div class=\"ngx-editor-message\" *ngIf=\"ngxMessage\" (dblclick)=\"clearMessage()\">\n  {{ ngxMessage }}\n</div>\n",
                styles: [".ngx-editor-message{\n  font-size:80%;\n  background-color:#f1f1f1;\n  border:1px solid #ddd;\n  border-top:transparent;\n  padding:0 0.5rem;\n  padding-bottom:0.1rem;\n  -webkit-transition:0.5s ease-in;\n  transition:0.5s ease-in; }\n"]
            },] },
];
/** @nocollapse */
NgxEditorMessageComponent.ctorParameters = function () { return [
    { type: MessageService, },
]; };
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxEditorToolbarComponent = /** @class */ (function () {
    /**
     * @param {?} _popOverConfig
     * @param {?} _formBuilder
     * @param {?} _messageService
     * @param {?} _commandExecutorService
     */
    function NgxEditorToolbarComponent(_popOverConfig, _formBuilder, _messageService, _commandExecutorService) {
        this._popOverConfig = _popOverConfig;
        this._formBuilder = _formBuilder;
        this._messageService = _messageService;
        this._commandExecutorService = _commandExecutorService;
        this.isImageUploader = true;
        this.uploadComplete = true;
        this.updloadPercentage = 0;
        this.isUploading = false;
        /**
         * Emits an event when a toolbar button is clicked
         */
        this.execute = new EventEmitter();
        this._popOverConfig.outsideClick = true;
        this._popOverConfig.placement = 'bottom';
        this._popOverConfig.container = 'body';
    }
    /**
     * enable or diable toolbar based on configuration
     *
     * @param {?} value name of the toolbar buttons
     * @return {?}
     */
    NgxEditorToolbarComponent.prototype.canEnableToolbarOptions = function (value) {
        return canEnableToolbarOptions(value, this.config['toolbar']);
    };
    /**
     * triggers command from the toolbar to be executed and emits an event
     *
     * @param {?} command name of the command to be executed
     * @return {?}
     */
    NgxEditorToolbarComponent.prototype.triggerCommand = function (command) {
        this.execute.emit(command);
    };
    /**
     * create URL insert form
     * @return {?}
     */
    NgxEditorToolbarComponent.prototype.buildUrlForm = function () {
        this.urlForm = this._formBuilder.group({
            urlLink: ['', [Validators.required]],
            urlText: ['', [Validators.required]],
            urlNewTab: [true]
        });
        return;
    };
    /**
     * insert link
     * @return {?}
     */
    NgxEditorToolbarComponent.prototype.insertLink = function () {
        try {
            this._commandExecutorService.createLink(this.urlForm.value);
        }
        catch (error) {
            this._messageService.sendMessage(error.message);
        }
        /** reset form to default */
        this.buildUrlForm();
        /** close inset URL pop up */
        this.urlPopover.hide();
        return;
    };
    /**
     * create insert image form
     * @return {?}
     */
    NgxEditorToolbarComponent.prototype.buildInsertImageForm = function () {
        this.imageForm = this._formBuilder.group({
            imageUrl: ['', [Validators.required]]
        });
        return;
    };
    /**
     * @param {?} e
     * @return {?}
     */
    NgxEditorToolbarComponent.prototype.onFileChange = function (e) {
        var _this = this;
        this.uploadComplete = false;
        this.isUploading = true;
        if (e.target.files.length > 0) {
            var /** @type {?} */ file = e.target.files[0];
            try {
                this._commandExecutorService.uploadImage(file, this.config.imageEndPoint).subscribe(function (event) {
                    if (event.type) {
                        _this.updloadPercentage = Math.round(100 * event.loaded / event.total);
                    }
                    if (event instanceof HttpResponse) {
                        try {
                            _this._commandExecutorService.insertImage(event.body.url);
                        }
                        catch (error) {
                            _this._messageService.sendMessage(error.message);
                        }
                        _this.uploadComplete = true;
                        _this.isUploading = false;
                    }
                });
            }
            catch (error) {
                this._messageService.sendMessage(error.message);
                this.uploadComplete = true;
                this.isUploading = false;
            }
        }
        return;
    };
    /**
     * @return {?}
     */
    NgxEditorToolbarComponent.prototype.insertImage = function () {
        try {
            this._commandExecutorService.insertImage(this.imageForm.value.imageUrl);
        }
        catch (error) {
            this._messageService.sendMessage(error.message);
        }
        /** reset form to default */
        this.buildInsertImageForm();
        /** close inset URL pop up */
        this.imagePopover.hide();
    };
    /**
     * @return {?}
     */
    NgxEditorToolbarComponent.prototype.ngOnInit = function () {
        this.buildUrlForm();
        this.buildInsertImageForm();
    };
    return NgxEditorToolbarComponent;
}());
NgxEditorToolbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-ngx-editor-toolbar',
                template: "<div class=\"ngx-toolbar\" *ngIf=\"config['showToolbar']\">\n  <div class=\"ngx-toolbar-set\">\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('bold')\" (click)=\"triggerCommand('bold')\"\n      title=\"Bold\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-bold\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('italic')\" (click)=\"triggerCommand('italic')\"\n      title=\"Italic\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-italic\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('underline')\" (click)=\"triggerCommand('underline')\"\n      title=\"Underline\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-underline\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('strikeThrough')\" (click)=\"triggerCommand('strikeThrough')\"\n      title=\"Strikethrough\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-strikethrough\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('superscript')\" (click)=\"triggerCommand('superscript')\"\n      title=\"Superscript\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-superscript\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('subscript')\" (click)=\"triggerCommand('subscript')\"\n      title=\"Subscript\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-subscript\" aria-hidden=\"true\"></i>\n    </button>\n  </div>\n  <div class=\"ngx-toolbar-set\">\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('justifyLeft')\" (click)=\"triggerCommand('justifyLeft')\"\n      title=\"Justify Left\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-align-left\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('justifyCenter')\" (click)=\"triggerCommand('justifyCenter')\"\n      title=\"Justify Center\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-align-center\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('justifyRight')\" (click)=\"triggerCommand('justifyRight')\"\n      title=\"Justify Right\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-align-right\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('justifyFull')\" (click)=\"triggerCommand('justifyFull')\"\n      title=\"Justify\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-align-justify\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('indent')\" (click)=\"triggerCommand('indent')\"\n      title=\"Indent\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-indent\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('outdent')\" (click)=\"triggerCommand('outdent')\"\n      title=\"Outdent\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-outdent\" aria-hidden=\"true\"></i>\n    </button>\n  </div>\n  <div class=\"ngx-toolbar-set\">\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('cut')\" (click)=\"triggerCommand('cut')\" title=\"Cut\"\n      [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-scissors\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('copy')\" (click)=\"triggerCommand('copy')\"\n      title=\"Copy\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-files-o\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('delete')\" (click)=\"triggerCommand('delete')\"\n      title=\"Delete\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-trash\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('removeFormat')\" (click)=\"triggerCommand('removeFormat')\"\n      title=\"Clear Formatting\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-eraser\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('undo')\" (click)=\"triggerCommand('undo')\"\n      title=\"Undo\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-undo\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('redo')\" (click)=\"triggerCommand('redo')\"\n      title=\"Redo\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-repeat\" aria-hidden=\"true\"></i>\n    </button>\n  </div>\n  <div class=\"ngx-toolbar-set\">\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('paragraph')\" (click)=\"triggerCommand('insertParagraph')\"\n      title=\"Paragraph\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-paragraph\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('blockquote')\" (click)=\"triggerCommand('blockquote')\"\n      title=\"Blockquote\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-quote-left\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('removeBlockquote')\" (click)=\"triggerCommand('removeBlockquote')\"\n      title=\"Remove Blockquote\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-quote-right\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('horizontalLine')\" (click)=\"triggerCommand('insertHorizontalRule')\"\n      title=\"Horizontal Line\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-minus\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('orderedList')\" (click)=\"triggerCommand('insertUnorderedList')\"\n      title=\"Unodered List\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-list-ul\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('unorderedList')\" (click)=\"triggerCommand('insertOrderedList')\"\n      title=\"Ordered List\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-list-ol\" aria-hidden=\"true\"></i>\n    </button>\n  </div>\n  <div class=\"ngx-toolbar-set\">\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('link')\" (click)=\"buildUrlForm()\" [popover]=\"insertLinkTemplate\"\n      title=\"Insert Link\" #urlPopover=\"bs-popover\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-link\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('unlink')\" (click)=\"triggerCommand('unlink')\"\n      title=\"Unlink\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-chain-broken\" aria-hidden=\"true\"></i>\n    </button>\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('image')\" (click)=\"buildInsertImageForm()\"\n      title=\"Insert Image\" [popover]=\"insertImageTemplate\" #imagePopover=\"bs-popover\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-picture-o\" aria-hidden=\"true\"></i>\n    </button>\n  </div>\n  <div class=\"ngx-toolbar-set\">\n    <button type=\"button\" class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('code')\" (click)=\"triggerCommand('code')\"\n      title=\"View Code\" [disabled]=\"!config['enableToolbar']\">\n      <i class=\"fa fa-code\" aria-hidden=\"true\"></i>\n    </button>\n  </div>\n</div>\n<!-- URL Popover template -->\n<ng-template #insertLinkTemplate>\n  <div class=\"ngxe-popover-form extra-gt\">\n    <form [formGroup]=\"urlForm\" (ngSubmit)=\"urlForm.valid && insertLink()\" autocomplete=\"off\">\n      <div class=\"form-group\">\n        <label for=\"urlInput\" class=\"small\">URL</label>\n        <input type=\"text\" class=\"form-control-sm\" id=\"URLInput\" placeholder=\"URL\" formControlName=\"urlLink\" required>\n      </div>\n      <div class=\"form-group\">\n        <label for=\"urlTextInput\" class=\"small\">Text</label>\n        <input type=\"text\" class=\"form-control-sm\" id=\"urlTextInput\" placeholder=\"Text\" formControlName=\"urlText\" required>\n      </div>\n      <div class=\"form-check\">\n        <input type=\"checkbox\" class=\"form-check-input\" id=\"urlNewTab\" formControlName=\"urlNewTab\">\n        <label class=\"form-check-label\" for=\"urlNewTab\">Open in new tab</label>\n      </div>\n      <button type=\"submit\" class=\"btn-primary btn-sm btn\">Submit</button>\n    </form>\n  </div>\n</ng-template>\n<!-- Image Uploader Popover template -->\n<ng-template #insertImageTemplate>\n  <div class=\"ngxe-popover-form image-ctnr\">\n    <div class=\"imgc-topbar\">\n      <button type=\"button\" class=\"btn\" (click)=\"isImageUploader = true\">\n        <i class=\"fa fa-upload\"></i>\n      </button>\n      <button type=\"button\" class=\"btn\" (click)=\"isImageUploader = false\">\n        <i class=\"fa fa-link\"></i>\n      </button>\n    </div>\n    <div class=\"imgc-ctnt\">\n      <div *ngIf=\"isImageUploader; else insertImageLink\"> </div>\n      <div *ngIf=\"!isImageUploader; else imageUploder\"> </div>\n      <ng-template #imageUploder>\n        <div class=\"ngx-insert-img-ph\">\n          <p *ngIf=\"uploadComplete\">Choose Image</p>\n          <p *ngIf=\"!uploadComplete\">\n            <span>Uploading Image</span>\n            <br>\n            <span>{{ updloadPercentage }} %</span>\n          </p>\n          <div class=\"ngxe-img-upl-frm\">\n            <input type=\"file\" (change)=\"onFileChange($event)\" accept=\"image/*\" [disabled]=\"isUploading\" [style.cursor]=\"isUploading ? 'not-allowed': 'allowed'\">\n          </div>\n        </div>\n      </ng-template>\n      <ng-template #insertImageLink>\n        <form class=\"extra-gt\" [formGroup]=\"imageForm\" (ngSubmit)=\"imageForm.valid && insertImage()\" autocomplete=\"off\">\n          <div class=\"form-group\">\n            <label for=\"imageURLInput\" class=\"small\">URL</label>\n            <input type=\"text\" class=\"form-control-sm\" id=\"imageURLInput\" placeholder=\"URL\" formControlName=\"imageUrl\" required>\n          </div>\n          <button type=\"submit\" class=\"btn-primary btn-sm btn\">Submit</button>\n        </form>\n      </ng-template>\n      <div class=\"progress\" *ngIf=\"!uploadComplete\">\n        <div class=\"progress-bar progress-bar-striped progress-bar-animated bg-success\" [ngClass]=\"{'bg-danger': updloadPercentage<20, 'bg-warning': updloadPercentage<50, 'bg-success': updloadPercentage>=100}\"\n          [style.width.%]=\"updloadPercentage\"></div>\n      </div>\n    </div>\n  </div>\n</ng-template>\n",
                styles: [".ngx-toolbar{\n  background-color:#f5f5f5;\n  font-size:0.8rem;\n  padding:0.2rem;\n  border:1px solid #ddd; }\n  .ngx-toolbar .ngx-toolbar-set{\n    display:inline-block;\n    border-radius:5px;\n    background-color:white; }\n    .ngx-toolbar .ngx-toolbar-set .ngx-editor-button{\n      background-color:#f5f5f5;\n      background-color:transparent;\n      padding:0.4rem;\n      min-width:2.5rem;\n      float:left;\n      border:1px solid #ddd;\n      border-right:transparent; }\n      .ngx-toolbar .ngx-toolbar-set .ngx-editor-button:hover{\n        cursor:pointer;\n        background-color:#f1f1f1;\n        -webkit-transition:0.2s ease;\n        transition:0.2s ease; }\n      .ngx-toolbar .ngx-toolbar-set .ngx-editor-button:focus, .ngx-toolbar .ngx-toolbar-set .ngx-editor-button.focus{\n        outline:0; }\n      .ngx-toolbar .ngx-toolbar-set .ngx-editor-button:last-child{\n        border-right:1px solid #ddd; }\n      .ngx-toolbar .ngx-toolbar-set .ngx-editor-button:first-child{\n        border-top-left-radius:5px;\n        border-bottom-left-radius:5px; }\n      .ngx-toolbar .ngx-toolbar-set .ngx-editor-button:last-child{\n        border-top-right-radius:5px;\n        border-bottom-right-radius:5px; }\n      .ngx-toolbar .ngx-toolbar-set .ngx-editor-button:disabled{\n        background-color:#f5f5f5;\n        pointer-events:none;\n        cursor:not-allowed; }\n::ng-deep .popover{\n  border-top-right-radius:0;\n  border-top-left-radius:0; }\n::ng-deep .ngxe-popover-form{\n  min-width:15rem; }\n  ::ng-deep .ngxe-popover-form.extra-gt, ::ng-deep .ngxe-popover-form .extra-gt{\n    padding-top:0.5rem; }\n  ::ng-deep .ngxe-popover-form .form-group label{\n    display:none;\n    margin:0; }\n  ::ng-deep .ngxe-popover-form .form-group .form-control-sm{\n    width:100%;\n    outline:none;\n    border:none;\n    border-bottom:solid 1px #bdbdbd;\n    border-radius:0;\n    margin-bottom:1px;\n    padding-left:0;\n    padding-right:0; }\n    ::ng-deep .ngxe-popover-form .form-group .form-control-sm:focus, ::ng-deep .ngxe-popover-form .form-group .form-control-sm:active{\n      border-bottom:2px solid #1e88e5;\n      -webkit-box-shadow:none;\n              box-shadow:none;\n      margin-bottom:0; }\n    ::ng-deep .ngxe-popover-form .form-group .form-control-sm.ng-dirty.ng-invalid:not(.ng-pristine){\n      border-bottom:2px solid red; }\n  ::ng-deep .ngxe-popover-form .form-check{\n    margin-bottom:1rem; }\n  ::ng-deep .ngxe-popover-form .btn:focus{\n    -webkit-box-shadow:none !important;\n            box-shadow:none !important; }\n  ::ng-deep .ngxe-popover-form.image-ctnr{\n    margin:-0.5rem -0.75rem; }\n    ::ng-deep .ngxe-popover-form.image-ctnr .imgc-topbar{\n      -webkit-box-shadow:0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 1px 1px rgba(0, 0, 0, 0.16);\n              box-shadow:0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 1px 1px rgba(0, 0, 0, 0.16);\n      border-bottom:0px; }\n      ::ng-deep .ngxe-popover-form.image-ctnr .imgc-topbar button{\n        background-color:transparent; }\n        ::ng-deep .ngxe-popover-form.image-ctnr .imgc-topbar button:hover{\n          cursor:pointer;\n          background-color:#f1f1f1;\n          -webkit-transition:0.2s ease;\n          transition:0.2s ease; }\n    ::ng-deep .ngxe-popover-form.image-ctnr .imgc-ctnt{\n      padding:0.5rem; }\n      ::ng-deep .ngxe-popover-form.image-ctnr .imgc-ctnt .progress{\n        height:0.5rem;\n        margin:0.5rem -0.5rem -0.6rem -0.5rem; }\n      ::ng-deep .ngxe-popover-form.image-ctnr .imgc-ctnt p{\n        margin:0; }\n      ::ng-deep .ngxe-popover-form.image-ctnr .imgc-ctnt .ngx-insert-img-ph{\n        border:dashed 2px #bdbdbd;\n        padding:1.8rem 0;\n        position:relative;\n        letter-spacing:1px;\n        text-align:center; }\n        ::ng-deep .ngxe-popover-form.image-ctnr .imgc-ctnt .ngx-insert-img-ph:hover{\n          background:#ebebeb; }\n        ::ng-deep .ngxe-popover-form.image-ctnr .imgc-ctnt .ngx-insert-img-ph .ngxe-img-upl-frm{\n          opacity:0;\n          position:absolute;\n          top:0;\n          bottom:0;\n          left:0;\n          right:0;\n          z-index:2147483640;\n          overflow:hidden;\n          margin:0;\n          padding:0;\n          width:100%; }\n          ::ng-deep .ngxe-popover-form.image-ctnr .imgc-ctnt .ngx-insert-img-ph .ngxe-img-upl-frm input{\n            cursor:pointer;\n            position:absolute;\n            right:0px;\n            top:0px;\n            bottom:0px;\n            margin:0px; }\n"],
                providers: [PopoverConfig]
            },] },
];
/** @nocollapse */
NgxEditorToolbarComponent.ctorParameters = function () { return [
    { type: PopoverConfig, },
    { type: FormBuilder, },
    { type: MessageService, },
    { type: CommandExecutorService, },
]; };
NgxEditorToolbarComponent.propDecorators = {
    "config": [{ type: Input },],
    "urlPopover": [{ type: ViewChild, args: ['urlPopover',] },],
    "imagePopover": [{ type: ViewChild, args: ['imagePopover',] },],
    "execute": [{ type: Output },],
};
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxEditorModule = /** @class */ (function () {
    function NgxEditorModule() {
    }
    return NgxEditorModule;
}());
NgxEditorModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule, ReactiveFormsModule, PopoverModule.forRoot()],
                declarations: [NgxEditorComponent, NgxGrippieComponent, NgxEditorMessageComponent, NgxEditorToolbarComponent],
                exports: [NgxEditorComponent, PopoverModule],
                providers: [CommandExecutorService, MessageService]
            },] },
];
/** @nocollapse */
NgxEditorModule.ctorParameters = function () { return []; };
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */
export { NgxEditorModule, CommandExecutorService as ɵc, MessageService as ɵb, NgxEditorMessageComponent as ɵe, NgxEditorToolbarComponent as ɵf, NgxEditorComponent as ɵa, NgxGrippieComponent as ɵd };
//# sourceMappingURL=ngx-editor.js.map
